@@ -14,7 +14,18 @@ use Time::Piece;
 
 no warnings 'experimental';
 
-our $VERSION='0.009';
+
+our $VERSION='0.010';
+
+=head1 NAME
+
+Vote::Count
+
+=head1 VERSION 0.010
+
+=cut
+
+# ABSTRACT: Parent Module for Vote::Count. Toolkit for vote counting.
 
 has 'BallotSet' => ( is => 'ro', isa => 'HashRef' );
 has 'BallotSetType' => (
@@ -90,3 +101,25 @@ sub CountBallots ( $self ) {
 __PACKAGE__->meta->make_immutable;
 1;
 
+#FOOTER
+
+=pod
+
+BUG TRACKER
+
+L<https://github.com/brainbuz/Vote-Count/issues>
+
+AUTHOR
+
+John Karr (BRAINBUZ) brainbuz@cpan.org
+
+CONTRIBUTORS
+
+Copyright 2019 by John Karr (BRAINBUZ) brainbuz@cpan.org.
+
+LICENSE
+
+This module is released under the GNU Public License Version 3. See license file for details. For more information on this license visit L<http://fsf.org>.
+
+=cut
+
