@@ -5,7 +5,7 @@ use 5.022;
 use feature qw /postderef signatures/;
 
 package Vote::Count::Approval;
-$Vote::Count::Approval::VERSION = '0.009';
+$Vote::Count::Approval::VERSION = '0.010';
 use Moose::Role;
 
 no warnings 'experimental';
@@ -32,4 +32,26 @@ sub Approval ( $self, $active=undef ) {
   return Vote::Count::RankCount->Rank( \%approval );
 }
 
-1;
\ No newline at end of file
+1;
+#FOOTER
+
+=pod
+
+BUG TRACKER
+
+L<https://github.com/brainbuz/Vote-Count/issues>
+
+AUTHOR
+
+John Karr (BRAINBUZ) brainbuz@cpan.org
+
+CONTRIBUTORS
+
+Copyright 2019 by John Karr (BRAINBUZ) brainbuz@cpan.org.
+
+LICENSE
+
+This module is released under the GNU Public License Version 3. See license file for details. For more information on this license visit L<http://fsf.org>.
+
+=cut
+
