@@ -7,7 +7,19 @@ package Vote::Count::Borda;
 
 use Moose::Role;
 
-our $VERSION='0.009';
+
+our $VERSION='0.010';
+
+=head1 NAME
+
+Vote::Count::Borda
+
+=head1 VERSION 0.010
+
+=cut
+
+# ABSTRACT: Provides Borda Count to Vote::Count objects
+
 no warnings 'experimental';
 use List::Util qw( min max );
 use Vote::Count::RankCount;
@@ -138,4 +150,28 @@ sub Borda ( $self, $active = undef ) {
   return Vote::Count::RankCount->Rank( $BordaCounted );
 }
 
-1;
\ No newline at end of file
+1;
+
+
+#FOOTER
+
+=pod
+
+BUG TRACKER
+
+L<https://github.com/brainbuz/Vote-Count/issues>
+
+AUTHOR
+
+John Karr (BRAINBUZ) brainbuz@cpan.org
+
+CONTRIBUTORS
+
+Copyright 2019 by John Karr (BRAINBUZ) brainbuz@cpan.org.
+
+LICENSE
+
+This module is released under the GNU Public License Version 3. See license file for details. For more information on this license visit L<http://fsf.org>.
+
+=cut
+
