@@ -4,7 +4,6 @@ use 5.022;
 use feature qw /postderef signatures/;
 
 package Vote::Count::Floor;
-$Vote::Count::Floor::VERSION = '0.009';
 use namespace::autoclean;
 use Moose::Role;
 
@@ -12,6 +11,18 @@ use Data::Printer;
 
 no warnings 'experimental';
 
+our $VERSION='0.010';
+
+=head1 NAME
+
+Vote::Count::Floor
+
+=head1 VERSION 0.010
+
+=cut
+
+# ABSTRACT: Floor Rules for RCV elections.
+
 # load the roles providing the underlying ops.
 with  'Vote::Count::Approval',
       'Vote::Count::TopCount',
@@ -86,5 +97,25 @@ sub TCA( $self ) {
 
 1;
 
+#FOOTER
+
 =pod
 
+BUG TRACKER
+
+L<https://github.com/brainbuz/Vote-Count/issues>
+
+AUTHOR
+
+John Karr (BRAINBUZ) brainbuz@cpan.org
+
+CONTRIBUTORS
+
+Copyright 2019 by John Karr (BRAINBUZ) brainbuz@cpan.org.
+
+LICENSE
+
+This module is released under the GNU Public License Version 3. See license file for details. For more information on this license visit L<http://fsf.org>.
+
+=cut
+
