@@ -3,13 +3,26 @@ use warnings;
 use 5.022;
 
 package Vote::Count::RankCount;
-$Vote::Count::RankCount::VERSION = '0.009';
+
 use feature qw /postderef signatures/;
 no warnings 'experimental';
 use List::Util qw( min max sum);
 use TextTableTiny  qw/generate_markdown_table/;
 # use boolean;
-use Data::Printer;
+# use Data::Printer;
+
+our $VERSION='0.010';
+
+=head1 NAME
+
+Vote::Count::RankCount
+
+=head1 VERSION 0.010
+
+=cut
+
+# ABSTRACT: RankCount object for Vote::Count. Toolkit for vote counting.
+
 
 sub _RankResult ( $rawcount ) {
   my %rc      = $rawcount->%*;    # destructive process needs to use a copy.
@@ -91,4 +104,28 @@ sub RankTable( $self ) {
   return generate_markdown_table( rows => \@rows );
 }
 
-1;
\ No newline at end of file
+1;
+
+#buildpod
+#FOOTER
+
+=pod
+
+BUG TRACKER
+
+L<https://github.com/brainbuz/Vote-Count/issues>
+
+AUTHOR
+
+John Karr (BRAINBUZ) brainbuz@cpan.org
+
+CONTRIBUTORS
+
+Copyright 2019 by John Karr (BRAINBUZ) brainbuz@cpan.org.
+
+LICENSE
+
+This module is released under the GNU Public License Version 3. See license file for details. For more information on this license visit L<http://fsf.org>.
+
+=cut
+
