@@ -1,5 +1,5 @@
 package Vote::Count::ReadBallots;
-$Vote::Count::ReadBallots::VERSION = '0.009';
+
 use 5.022;
 use feature qw/postderef signatures/;
 # use strict;
@@ -7,8 +7,20 @@ use feature qw/postderef signatures/;
 no warnings qw/experimental/;
 use Path::Tiny;
 use Carp;
-use Data::Dumper;
-use Data::Printer;
+# use Data::Dumper;
+# use Data::Printer;
+
+our $VERSION='0.010';
+
+=head1 NAME
+
+Vote::Count::ReadBallots
+
+=head1 VERSION 0.010
+
+=cut
+
+# ABSTRACT: Read Ballots for Vote::Count. Toolkit for vote counting.
 
 use Exporter::Easy (
        OK => [ qw( read_ballots ) ],
@@ -58,11 +70,28 @@ sub read_ballots( $filename ) {
   }
   return \%data ;
 }
-
-
-
-
-
-
-
 1;
+
+#buildpod
+#FOOTER
+
+=pod
+
+BUG TRACKER
+
+L<https://github.com/brainbuz/Vote-Count/issues>
+
+AUTHOR
+
+John Karr (BRAINBUZ) brainbuz@cpan.org
+
+CONTRIBUTORS
+
+Copyright 2019 by John Karr (BRAINBUZ) brainbuz@cpan.org.
+
+LICENSE
+
+This module is released under the GNU Public License Version 3. See license file for details. For more information on this license visit L<http://fsf.org>.
+
+=cut
+
