@@ -14,13 +14,29 @@ use TextTableTiny 'generate_markdown_table';
 # use boolean;
 # use Data::Printer;
 
-our $VERSION='0.009';
+# ABSTRACT: TopCount and related methods for Vote::Count. Toolkit for vote counting.
+
+our $VERSION='0.010';
 
 =head1 NAME
 
 Vote::Count::TopCount
 
-=head1 VERSION 0.009
+=head1 VERSION 0.010
+
+=head1 Synopsis
+
+This Role is consumed by Vote::Count it provides TopCount and related Methods to Vote::Count objects.
+
+=head2 Definition of Top Count
+
+Top Count is tabulation of the Top Choice vote on each ballot. As choices are eliminated the first choice on some ballots will be removed, the next highest remaining choice becomes the Top Choice for that ballot. When all choices on a ballot are eliminated it becomes exhausted and is no longer counted.
+
+=head2 Method TopCount
+
+Takes a hashref of active choices as an optional parameter, if one is not provided it uses the internal active list accessible via the ->Active() method, which itself defaults to the BallotSet's Choices list.
+
+Returns a RankCount object containing the TopCount.
 
 =cut
 
@@ -42,7 +58,7 @@ TOPCOUNTBALLOTS:
   return Vote::Count::RankCount->Rank( \%topcount );
 }
 
-=head2 TopCountMajority
+=head2 Method TopCountMajority
 
   $self->TopCountMajority( $round_topcount )
   or
@@ -81,7 +97,7 @@ sub TopCountMajority ( $self, $topcount = undef, $active = undef ) {
   );
 }
 
-=head2 EvaluateTopCountMajority
+=head2 Method EvaluateTopCountMajority
 
 This method wraps TopCountMajority adding logging, the logging of which would be a lot of boiler plate in round oriented methods. It takes the same parameters and returns the same hashref.
 
@@ -108,4 +124,26 @@ sub EvaluateTopCountMajority ( $self, $topcount = undef, $active = undef) {
   return $majority;
 }
 
-1;
\ No newline at end of file
+1;
+#FOOTER
+
+=pod
+
+BUG TRACKER
+
+L<https://github.com/brainbuz/Vote-Count/issues>
+
+AUTHOR
+
+John Karr (BRAINBUZ) brainbuz@cpan.org
+
+CONTRIBUTORS
+
+Copyright 2019 by John Karr (BRAINBUZ) brainbuz@cpan.org.
+
+LICENSE
+
+This module is released under the GNU Public License Version 3. See license file for details. For more information on this license visit L<http://fsf.org>.
+
+=cut
+
